#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <cmath>
#include <iomanip>
#include <cassert>
#include <array>
#include <random>
#include <chrono>
#include <map>
#include <set>
#include <queue>

using namespace std;
#define ll long long
struct Fenwick {
    int n;
    vector <int> f;

    Fenwick(int n) : n(n) {
        f.resize(n + 1);
    }

    Fenwick() {}

    inline void add(int i, int x) {
        for (++i; i <= n; i += (i & (-i))) f[i] += x;
    }

    inline int get_pref(int i) {
        int ans = 0;
        for (++i; i > 0; i -= (i & (-i))) ans += f[i];
        return ans;
    }

    inline int get_seg(int l, int r) {
        return get_pref(r) - get_pref(l - 1);
    }
};

struct MergeSortTree {
    int n;
    vector <vector <int>> t;
    vector <Fenwick> f;

    MergeSortTree(int n, vector <int>& a) : n(n) {
        t.resize(4 * n);
        f.resize(4 * n);
        build(1, 0, n - 1, a);
    }

    void build(int v, int l, int r, vector <int>& a) {
        if (l == r) {
            t[v] = {a[l]};
            f[v] = Fenwick(1);
            f[v].add(0, 1);
            return;
        }
        int m = (l + r) / 2;
        build(2 * v, l, m, a);
        build(2 * v + 1, m + 1, r, a);
        t[v].resize(r - l + 1);
        merge(t[2 * v].begin(), t[2 * v].end(), t[2 * v + 1].begin(), t[2 * v + 1].end(), t[v].begin());
        f[v] = Fenwick(r - l + 1);
        for (int i = 0; i < r - l + 1; ++i) f[v].add(i, 1);
    }

    void update(int v, int l, int r, int i, int x) {
        if (l > i || i > r) return;
        f[v].add(lower_bound(t[v].begin(), t[v].end(), x) - t[v].begin(), -1);
        if (l == r) return;
        int m = (l + r) / 2;
        update(2 * v, l, m, i, x);
        update(2 * v + 1, m + 1, r, i, x);
    }

    inline void update(int i, int x) {
        update(1, 0, n - 1, i, x);
    }

    int cnt_less(int v, int l, int r, int A, int B, int x) {
        if (l > B || A > r) return 0;
        if (A <= l && r <= B) return f[v].get_pref(lower_bound(t[v].begin(), t[v].end(), x) - t[v].begin() - 1);
        int m = (l + r) / 2;
        return cnt_less(2 * v, l, m, A, B, x) + cnt_less(2 * v + 1, m + 1, r, A, B, x);
    }

    inline int cnt_less(int l, int r, int x) {
        return cnt_less(1, 0, n - 1, l, r, x);
    }

    int cnt_more(int v, int l, int r, int A, int B, int x) {
        if (l > B || A > r) return 0;
        if (A <= l && r <= B) return f[v].get_seg(upper_bound(t[v].begin(), t[v].end(), x) - t[v].begin(), r - l);
        int m = (l + r) / 2;
        return cnt_more(2 * v, l, m, A, B, x) + cnt_more(2 * v + 1, m + 1, r, A, B, x);
    }

    inline int cnt_more(int l, int r, int x) {
        return cnt_more(1, 0, n - 1, l, r, x);
    }
};

void solve1() {
    int n;
    cin >> n;
    if (n <= 100) return;
    vector <int> a(n), pos(n + 1);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
        pos[a[i]] = i;
    }
    MergeSortTree t(n, a);
    ll ans = 0;
    for (int i = 0; i < n; ++i) {
        ans += t.cnt_more(0, i - 1, a[i]);
    }
    cout << ans << " ";
    for (int i = 0; i < n - 2; ++i) {
        int x;
        cin >> x;
        t.update(pos[x], x);
        ans -= t.cnt_more(0, pos[x] - 1, x);
        ans -= t.cnt_less(pos[x] + 1, n - 1, x);
        cout << ans << " ";
    }
}

signed main(int32_t arcg, char **argv) {
    if (1) {
        ios_base::sync_with_stdio(false);
        cin.tie(nullptr);
        cout.tie(nullptr);
    }
    if (1) {
        int t = 1;
        //cin >> t;
        while (t--) {
            solve1();
        }
    }
}

/*
6
6 1 2 5 3 4
3 5 4 6
 */