#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;
using ll = long long;

struct Fenwick {
    vector<int> t;
    int n;
    void init(int m) {
        n = m;
        t.assign(n + 1, 0);
    }

    void modify(int i, int val) {
        for (int x = i + 1; x <= n; x += x & -x) {
            t[x] += val;
        }
    }

    int sum(int i) {
        int ans = 0;
        for (int x = i + 1; x > 0; x -= x & -x) {
            ans += t[x];
        }
        return ans;
    }

    int rangeSum(int l, int r) {
        return sum(r - 1) - sum(l - 1);
    }
};

vector<vector<int>> t;
vector<Fenwick> fn;

int sz;

void init(int n, vector<pair<int, int>> a) {
    sz = n;
    t.assign(sz << 1, {}), fn.assign(sz << 1, {});

    sort(a.begin(), a.end());
    for (auto [val, i] : a) {
        for (int x = i + sz; x > 0; x >>= 1) {
            t[x].push_back(val);
        }
    }

    for (int x = 1; x < 2 * sz; ++x) {
        fn[x].init(t[x].size());
    }
}

void modify(int i, int val, int modifier) {
    for (int x = i + sz; x > 0; x >>= 1) {
        int it = lower_bound(t[x].begin(), t[x].end(), val) - t[x].begin();
        fn[x].modify(it, modifier);
    }
}

int vertexQuery(int x, int k) {
    int it = lower_bound(t[x].begin(), t[x].end(), k) - t[x].begin();
    return fn[x].sum(it - 1);
}

int rangeQuery(int l, int r, int k) {
    int ans = 0;
    for (l += sz, r += sz; l < r; l >>= 1, r >>= 1) {
        if (l & 1) ans += vertexQuery(l++, k);
        if (r & 1) ans += vertexQuery(--r, k);
    }
    return ans;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >> n;

    vector<int> a(n), place(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
        --a[i];
        place[a[i]] = i;
    }

    Fenwick s;
    s.init(n);

    ll ans = 0;
    vector<pair<int, int>> yy(n);
    for (int i = 0; i < n; ++i) {
        yy[i] = {a[i], i};
    }
    init(n, yy);

    for (int i = 0; i < n; ++i) {
        ans += i - rangeQuery(0, i, a[i]);
        modify(i, a[i], 1);
        s.modify(i, 1);
    }

    cout << ans << " ";
    for (int qq = 0; qq < n - 2; ++qq) {
        int x;
        cin >> x;
        --x;
        int i = place[x];

        ans -= s.sum(i - 1) - rangeQuery(0, i, x);
        ans -= rangeQuery(i + 1, n, x);

        s.modify(i, -1);
        modify(i, x, -1);

        cout << ans << ' ';
    }
    return 0;
}
