#include <iostream>
#include <vector>
#include <map>
#include <algorithm>

using namespace std;

const int NMAX = 1e5;
const int INF = 1e9;

int V[NMAX + 1];
int vpos[NMAX + 1];
int f[NMAX + 1];

struct Fenwick{
    int sz;
    vector <int> aib;

    void init(int Sz){
        aib = vector <int> (sz + 1, 0);
    }

    void trash(){
        aib.clear();
        sz = 0;
    }

    int lsb(int x){
        return x & -x;
    }

    void update(int pos, int val){
        for(int i = pos; i <= sz; i += lsb(i))
            aib[i] += val;
    }

    int query(int pos){
        int ans = 0;
        for(int i = pos; i >= 1; i -= lsb(i))
            ans += aib[i];
        return ans;
    }
};

struct Node{
    Fenwick DS;
    vector <int> v;
    map <int, int> mp;
};

Node aint[4 * NMAX + 1];

Node combine1(Node a, Node b){
    Node c;

    for(auto elem : a.v)
        c.v.push_back(elem);
    for(auto elem : b.v)
        c.v.push_back(elem);

    sort(c.v.begin(), c.v.end());

    c.DS.init((int)c.v.size());

    for(int i = 0; i < (int)c.v.size(); i++)
        c.mp[V[i]] = i + 1;

    return c;
}

void build(int nod, int st, int dr){
    if(st == dr){
        aint[nod].DS.init(1);
        aint[nod].v.push_back(V[st]);
        aint[nod].mp[V[st]] = 1;
        return;
    }

    int mij = (st + dr) / 2;
    build(2  * nod, st, mij);
    build(2 * nod + 1, mij + 1, dr);

    aint[nod] = combine1(aint[2 * nod], aint[2 * nod + 1]);
}

void update(int nod, int st, int dr, int pos){
    aint[nod].DS.update(aint[nod].mp[V[pos]], 1);

    int mij = (st + dr) / 2;
    if(pos <= mij)
        update(2 * nod, st, mij, pos);
    else
        update(2 * nod + 1, mij + 1, dr, pos);
}

int query1(int nod, int st, int dr, int L, int R, int val){
    if(L <= st && dr <= R){
        int pos = 0;
        auto it = aint[nod].mp.lower_bound(val);
        if(it != aint[nod].mp.begin())
            --it, pos = (*it).first;
        else
            pos = (int)aint[nod].v.size();

        return aint[nod].DS.query(pos);
    }

    int ansL = 0, ansR = 0;

    int mij = (st + dr) / 2;
    if(L <= mij)
        ansL += query1(2 * nod, st, mij, L, R, val);
    if(mij + 1 <= R)
        ansR += query1(2 * nod + 1, mij + 1, dr, L, R, val);

    return ansL + ansR;
}

int query2(int nod, int st, int dr, int L, int R, int val){
    if(L <= st && dr <= R){
        int pos = 0;
        auto it = aint[nod].mp.lower_bound(val);
        if(it != aint[nod].mp.begin())
            --it, pos = (*it).first;
        else
            pos = (int)aint[nod].v.size();

        return aint[nod].DS.query((int)aint[nod].v.size()) - aint[nod].DS.query(pos);
    }

    int ansL = 0, ansR = 0;

    int mij = (st + dr) / 2;
    if(L <= mij)
        ansL += query2(2 * nod, st, mij, L, R, val);
    if(mij + 1 <= R)
        ansR += query2(2 * nod + 1, mij + 1, dr, L, R, val);

    return ansL + ansR;
}

int queries[NMAX + 1];
int answer[NMAX + 1];

int main(){

    int n;
    cin >> n;

    for(int i = 1; i <= n; i++){
        cin >> V[i], vpos[V[i]] = i;
    }

    for(int i = 1; i <= n - 2; i++){
        cin >> queries[i];
        f[queries[i]]++;
    }

    build(1, 1, n);

    int a = -1;
    int b = -1;

    for(int i = 1; i <= n; i++){
        if(f[i] == 0){
            update(1, 1, n, vpos[i]);
            if(a == -1)
                a = i;
            else
                b = i;
        }
    }

    if(vpos[a] > vpos[b])
        swap(a, b);

    if(a > b)
        answer[n - 1] = 1;

    for(int i = n - 2; i >= 1; i--){
        answer[i] += query1(1, 1, n, vpos[queries[i]] + 1, n, queries[i]);
        answer[i] += query2(1, 1, n, 1, vpos[queries[i]] - 1, queries[i]);

        update(1, 1, n, vpos[queries[i]]);
    }

    for(int i = 1; i <= n; i++)
        cout << answer[i] << ' ';
    cout << '\n';

    return 0;
}



