#include <bits/stdc++.h>
#define ll long long
#define lg(x) (31-__builtin_clz(n))
#define highpow(x) (1 << lg(x))
#define bitcnt(x) (__builtin_popcount(x))
#define pb push_back
#define sp ' '
#define en '\n'
#define pv(v) for (auto x : v) cout << x << sp; cout << en;

using namespace std;

class AVL{

    int n, root;
    vector<ll> tree;
    vector<int> h, sz, l, r;
    queue<int> free;

    void Assign(int s, ll x){
        tree[s] = x;
        h[s] = sz[s] = 1;
        l[s] = r[s] = -1;
    }

    int Make(ll x){
        n++;
        int s = free.front(); free.pop();
        Assign(s, x);
        return s;
    }

    void Erase(int s){
        free.push(s);
        n--;
    }

    int Height(int s) const { return (~s ? h[s] : 0); }
    int Size(int s) const { return (~s ? sz[s] : 0); }

    void Update(int s){ h[s] = max(Height(l[s]), Height(r[s])) + 1; sz[s] = Size(l[s]) + Size(r[s]) + 1; }

    int Rrot(int s){
        int u = l[s];
        l[s] = r[u];
        r[u] = s;
        Update(s); Update(u);
        return u;
    }

    int Lrot(int s){
        int u = r[s];
        r[s] = l[u];
        l[u] = s;
        Update(s); Update(u);
        return u;
    }

    ll Min(int s) const { if (!~l[s]) return tree[s]; return Min(l[s]); }
    ll Max(int s) const { if (!~r[s]) return tree[s]; return Max(r[s]); }

    int BF(int s) const { return Height(l[s]) - Height(r[s]); }

    int Balance(int s){
        if (BF(s) < -1){
            if (BF(r[s]) > 0) r[s] = Rrot(r[s]);
            s = Lrot(s);
        }
        else if (BF(s) > 1){
            if (BF(l[s]) < 0) l[s] = Lrot(l[s]);
            s = Rrot(s);
        }
        return s;
    }

    int Insert(int s, ll x){
        if (!~s) return Make(x);
        if (x < tree[s]) l[s] = Insert(l[s], x);
        else r[s] = Insert(r[s], x);
        Update(s);
        return Balance(s);
    }

    int Delete(int s, ll x){
        if (!~s) return s;
        if (x == tree[s]){
            if (!~l[s] && !~r[s]){ Erase(s); return -1; }
            if (!~r[s]){
                int v = Max(l[s]);
                tree[s] = v;
                l[s] = Delete(l[s], v);
            }
            else{
                int v = Min(r[s]);
                tree[s] = v;
                r[s] = Delete(r[s], v);
            }
        }
        else if (x < tree[s]) l[s] = Delete(l[s], x);
        else r[s] = Delete(r[s], x);
        Update(s);
        return Balance(s);
    }

    int Get(int s, ll x) const {
        if (!~s) return 0;
        if (x == tree[s]) return Size(r[s]);
        if (x > tree[s]) return Get(r[s], x);
        return Size(r[s]) + 1 + Get(l[s], x);
    }

    vector<int> Dfs(int s) const {
        if (!~s) return {};
        vector<int> v = {s};
        auto a = Dfs(l[s]);
        auto b = Dfs(r[s]);
        for (int u : a) v.pb(u);
        for (int u : b) v.pb(u);
        return v;
    }

public:
    void Assign(int s){
        n = 0; root = -1;
        tree.resize(s); h.resize(s); sz.resize(s); l.resize(s); r.resize(s);
        for (int i = 0; i < s; i++) free.push(i);
    }
    void Insert(ll x){ root = Insert(root, x); }
    void Delete(ll x){ root = Delete(root, x); }
    int Get(ll x) const { return Get(root, x); }
    int Size() const { return Size(root); }

    void Print() const {
        auto v = Dfs(root);
        for (int s : v)
            cout << tree[s] << ": " << (~l[s] ? tree[l[s]] : -1) << sp << (~r[s] ? tree[r[s]] : -1) << en;
        cout.flush();
    }
};

class segtree{

    int n;
    vector<AVL> tree;

    void build(int s, int l, int r, vector<int> v){
        tree[s].Assign(r-l+1);
        for (int i = l; i <= r; i++) tree[s].Insert(v[i]);
        if (l == r) return;
        int m = (l + r)>>1;
        build(2*s, l, m, v);
        build(2*s+1, m+1, r, v);
    }

    void update(int s, int l, int r, int pos, int x){
        tree[s].Delete(x);
        if (l == r) return;
        int m = (l + r)>>1;
        if (pos <= m) update(2*s, l, m, pos, x);
        else update(2*s+1, m+1, r, pos, x);
    }

    int query(int s, int l, int r, int ql, int qr, int x, bool f) const {
        if (l > qr || r < ql) return 0;
        if (l >= ql && r <= qr){
            int cnt = tree[s].Get(x);
            if (!f) cnt = tree[s].Size() - cnt;
            return cnt;
        }
        int m = (l + r)>>1;
        int a = query(2*s, l, m, ql, qr, x, f);
        int b = query(2*s+1, m+1, r, ql, qr, x, f);
        return a+b;
    }

public:
    void Assign(int s, vector<int> v){
        n = (1 << (31 - __builtin_clz(s)));
        if (bitcnt(s) > 1) n <<= 1;
        tree.assign(2*n, AVL());
        build(1, 0, n-1, v);
    }
    void update(int pos, int x){ update(1, 0, n-1, pos, x); }
    int query(int l, int r, int x, bool f) const { if (l>r) return 0; return query(1, 0, n-1, l, r, x, f); }
};

const int mxN = 1e5+10, INF = 1e9;
ll n, m, a[mxN], mp[mxN];
vector<int> v;
segtree st;

ll MergeSort(vector<int>& v){

    if (v.size() == 1) return 0;
    int m = v.size() / 2;
    vector<int> a(v.begin(), v.begin()+m);
    vector<int> b(v.begin()+m, v.end());
    ll ans = MergeSort(a);
    ans += MergeSort(b);
    v.clear();
    int i = 0, j = 0;
    while (i < a.size() && j < b.size()){
        if (a[i] > b[j]){
            ans++;
            v.pb(b[j++]);
        }
        else v.pb(a[i++]);
    }
    while (i < a.size()) v.pb(a[i++]);
    while (j < b.size()) v.pb(b[j++]);
    return ans;
}

int main(){
    ios::sync_with_stdio(false);
    cin.tie(0); cout.tie(0);

    cin >> n;
    v.assign(n, 0);
    for (int i = 0; i < n; i++){
        cin >> a[i];
        v[i] = a[i];
        mp[a[i]] = i;
    }
    st.Assign(n, v);
    ll ans = MergeSort(v);
    cout << ans << sp;
    for (int i = 0; i < n-2; i++){
        int x; cin >> x;
        int pos = mp[x];
        st.update(pos, x);
        ll cnt = st.query(0, pos-1, x, 1) + st.query(pos+1, n-1, x, 0);
        ans -= cnt;
        cout << ans << sp;
    }
    cout << en;

    return 0;
}
